======
sigma0
======

.. image:: https://travis-ci.org/TUW-GEO/sigma0.svg?branch=master
    :target: https://travis-ci.org/TUW-GEO/sigma0

.. image:: https://coveralls.io/repos/github/TUW-GEO/sigma0/badge.svg?branch=master
   :target: https://coveralls.io/github/TUW-GEO/sigma0?branch=master

.. image:: https://badge.fury.io/py/sigma0.svg
    :target: https://badge.fury.io/py/sigma0

.. image:: https://readthedocs.org/projects/sigma0/badge/?version=latest
   :target: http://sigma0.readthedocs.org/

Citation
========

Not yet

Installation
============

This package should be installable through pip:

.. code::

    pip install sigma0

Contribute
==========

We are happy if you want to contribute. Please raise an issue explaining what
is missing or if you find a bug. We will also gladly accept pull requests
against our master branch for new features or bug fixes.

Guidelines
----------

If you want to contribute please follow these steps:

- Fork the sigma0 repository to your account
- make a new feature branch from the sigma0 master branch
- Add your feature
- Please include tests for your contributions in one of the test directories.
  We use py.test so a simple function called test_my_feature is enough
- submit a pull request to our master branch


Note
====

This project has been set up using PyScaffold 3.2.3. For details and usage
information on PyScaffold see https://pyscaffold.org/.
